@@ -44,12 +44,23 @@ LearnerClust = R6Class("LearnerClust",
 
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(id, param_set = ps(), predict_types = "partition", feature_types = character(),
-      properties = character(), packages = character(), label = NA_character_, man = NA_character_) {
+    initialize = function(
+      id,
+      param_set = ps(),
+      predict_types = "partition",
+      feature_types = character(),
+      properties = character(),
+      packages = character(),
+      label = NA_character_,
+      man = NA_character_
+    ) {
       super$initialize(
-        id = id, task_type = "clust", param_set = param_set,
+        id = id,
+        task_type = "clust",
+        param_set = param_set,
         predict_types = predict_types,
-        feature_types = feature_types, properties = properties,
+        feature_types = feature_types,
+        properties = properties,
         packages = c("mlr3cluster", packages),
         label = label,
         man = man
