@@ -61,7 +61,7 @@ LearnerClustDiana = R6Class("LearnerClustDiana",
     .predict = function(task) {
       pv = self$param_set$get_values(tags = "predict")
       if (pv$k > task$nrow) {
-        stopf("`k` needs to be between 1 and %s", task$nrow)
+        stopf("`k` needs to be between 1 and %i.", task$nrow)
       }
 
       warn_prediction_useless(self$id)
