@@ -48,12 +48,13 @@ as_prediction_clust.data.frame = function(x, ...) { # nolint
   assert_names(names(x), must.include = c("row_ids", "partition"))
   prob_cols = setdiff(names(x), c("row_ids", "partition"))
 
-  if (length(prob_cols)) {
+  if (length(prob_cols) > 0L) {
     if (!all(startsWith(prob_cols, "prob."))) {
-      stopf("Table may only contain columns 'row_ids', 'partition' as well as columns prefixed with 'prob.' for class probabilities") # nolint
+      stopf("Table may only contain columns 'row_ids', 'partition' as well as columns prefixed with 'prob.' for class probabilities.") # nolint
     }
     prob = as.matrix(x[, prob_cols, with = FALSE])
-    colnames(prob) = substr(colnames(prob), 6L, nchar(colnames(prob)))
+    nms = colnames(prob)
+    colnames(prob) = substr(nms, 6L, nchar(nms))
   } else {
     prob = NULL
   }
