@@ -34,7 +34,7 @@ as_task_clust.data.frame = function(x, id = deparse1(substitute(x)), ...) { # no
   force(id)
 
   ii = which(map_lgl(keep(x, is.double), anyInfinite))
-  if (length(ii)) {
+  if (length(ii) > 0L) {
     warningf("Detected columns with unsupported Inf values in data: %s", str_collapse(names(ii)))
   }
 
@@ -59,7 +59,7 @@ as_task_clust.formula = function(x, data, id = deparse1(substitute(data)), ...)
   assert_data_frame(data)
   assert_subset(all.vars(x), c(names(data), "."), .var.name = "formula")
   if (attributes(terms(x, data = data))$response) {
-    stopf("Formula %s has a response", format(x))
+    stopf("Formula %s has a response.", format(x))
   }
   tab = model.frame(x, data, na.action = "na.pass")
   attr(tab, "terms") = attr(tab, "na.action") = NULL
