@@ -1,6 +1,5 @@
 warn_prediction_useless = function(id) {
-  msg = sprintf("Learner '%s' doesn't predict on new data and predictions may not make sense on new data", id)
-  warning(warningCondition(msg, class = "predictionUselessWarning"))
+  warningf("Learner '%s' doesn't predict on new data and predictions may not make sense on new data.", id)
 }
 
 allow_partial_matching = list(
@@ -9,7 +8,7 @@ allow_partial_matching = list(
   warnPartialMatchDollar = FALSE
 )
 
-check_centers_param = function(centers, task, test_class, name) {
+assert_centers_param = function(centers, task, test_class, name) {
   if (test_class(centers) && ncol(centers) != task$ncol) {
     stopf("`%s` must have same number of columns as data.", name)
   }
