@@ -1,5 +1,5 @@
 test_that("autotest", {
-  learner = mlr3::lrn("clust.featureless")
+  learner = lrn("clust.featureless")
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
@@ -24,10 +24,10 @@ test_that("Learner properties are respected", {
     p = learner$train(task)$predict(task)
     expect_prediction_clust(p)
 
-    if ("complete" %in% learner$properties) {
+    if ("complete" %chin% learner$properties) {
       expect_prediction_complete(p, learner$predict_type)
     }
-    if ("exclusive" %in% learner$properties) {
+    if ("exclusive" %chin% learner$properties) {
       expect_prediction_exclusive(p, learner$predict_type)
     }
   }
